pub enum ClassDescRef {
Inline(Box<ClassDesc>),
Null,
Reference {
handle: u32,
},
}Expand description
Reference to a class descriptor - either inline or a back-reference.
Variants
Inline(Box<ClassDesc>)
Inline class descriptor.
Null
Null reference (no superclass).
Reference
Back-reference to a previously seen class descriptor by handle.
Implementations
Sourceimpl ClassDescRef
impl ClassDescRef
Sourcepub fn class_name(&self) -> Option<&str>
pub fn class_name(&self) -> Option<&str>
Try to get the class name from this class descriptor reference. Returns None for Null references and unresolved Reference types.